@@ -95,7 +95,7 @@ void cron_close_security_session( void );
 
 int cron_change_user( struct passwd *pw, char *homedir );
 
-int cron_get_job_context( user *u, void *scontextp, void *file_contextp, char **envp );
+int cron_change_user_permanently( struct passwd *pw );
 
 int get_security_context(const char *name, 
 			 int crontab_fd, 
